You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by lo...@apache.org on 2007/12/12 11:37:32 UTC

svn commit: r603542 - /myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrud.java

Author: lofwyr
Date: Wed Dec 12 02:37:31 2007
New Revision: 603542

URL: http://svn.apache.org/viewvc?rev=603542&view=rev
Log:
TOBAGO-519: Renaming

Added:
    myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrud.java
      - copied, changed from r603513, myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrudController.java

Copied: myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrud.java (from r603513, myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrudController.java)
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrud.java?p2=myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrud.java&p1=myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrudController.java&r1=603513&r2=603542&rev=603542&view=diff
==============================================================================
--- myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrudController.java (original)
+++ myfaces/tobago/trunk/sandbox/src/main/java/org/apache/myfaces/tobago/model/AbstractCrud.java Wed Dec 12 02:37:31 2007
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-public abstract class AbstractCrudController implements Crud {
+public abstract class AbstractCrud implements Crud {
 
   private String defaultOutcome;
 
@@ -25,7 +25,7 @@
 
   private boolean itemEditable;
 
-  protected AbstractCrudController() {
+  protected AbstractCrud() {
     reset();
   }
 
@@ -54,7 +54,7 @@
   /**
    * <p>
    * Hook for the implementation of business logic, after invoking the action
    * {@link AbstractCrudController#deleteItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
    * </p>
@@ -68,7 +68,7 @@
    */
   public final String showItem() {
     itemEditable = false;
-    showDetail = doShowItem() ? true : false;
+    showDetail = doShowItem();
     return getDefaultOutcome();
   }
 
@@ -77,14 +77,14 @@
    */
   public final String editItem() {
     itemEditable = true;
-    showDetail = doShowItem() ? true : false;
+    showDetail = doShowItem();
     return getDefaultOutcome();
   }
 
   /**
    * <p>
    * Hook for the implementation of business logic, after invoking the action
    * {@link AbstractCrudController#showItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
    * </p>
@@ -98,14 +98,14 @@
    */
   public final String createItem() {
     itemEditable = true;
-    showDetail = doCreateItem() ? true : false;
+    showDetail = doCreateItem();
     return getDefaultOutcome();
   }
 
   /**
    * <p>
    * Hook for the implementation of business logic, after invoking the action
    * {@link AbstractCrudController#createItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
    * </p>
@@ -118,14 +118,14 @@
    * @see Crud#saveItem()
    */
   public final String saveItem() {
-    showDetail = doSaveItem() ? false : true;
+    showDetail = !doSaveItem();
     return getDefaultOutcome();
   }
 
   /**
    * <p>
    * Hook for the implementation of business logic, after invoking the action
    * {@link AbstractCrudController#saveItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
    * </p>
@@ -147,7 +147,7 @@
   // /**
   // * <p>
   // * Hook for the implementation of business logic, after invoking the action
-  // {@link AbstractCrudController#cancelItem()}.
+  // {@link AbstractCrud#cancelItem()}.
   // * </p>
   // */
   // public abstract void doCancelItem();
@@ -54,7 +54,7 @@
    * <p>
    * Hook for the implementation of business logic, after invoking the action
-   * {@link AbstractCrudController#deleteItem()}. If the execution of the
+   * {@link AbstractCrud#deleteItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
@@ -77,14 +77,14 @@
    * <p>
    * Hook for the implementation of business logic, after invoking the action
-   * {@link AbstractCrudController#showItem()}. If the execution of the
+   * {@link AbstractCrud#showItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
@@ -98,14 +98,14 @@
    * <p>
    * Hook for the implementation of business logic, after invoking the action
-   * {@link AbstractCrudController#createItem()}. If the execution of the
+   * {@link AbstractCrud#createItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.
@@ -118,14 +118,14 @@
    * <p>
    * Hook for the implementation of business logic, after invoking the action
-   * {@link AbstractCrudController#saveItem()}. If the execution of the
+   * {@link AbstractCrud#saveItem()}. If the execution of the
    * business logic completed successfully, the method has to return <i>true</i>.
    * Otherwise the method has to return <i>false</i>.